pywurfl.wurflprocessor.DeviceHandler

Package pywurfl :: Module wurflprocessor :: Class DeviceHandler |
[hide private]
[frames] | no frames]

# Class DeviceHandler

source code

    object --+
             |
            DeviceHandler

Known Subclasses:
  wurfl2python.DeviceSerializer

Base class for DeviceHandler objects

Instance Methods | [hide private]
__init__(self, device) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, device) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Parameters: `device` (elementtree.Element) - An elementtree.Element instance of a device element in a WURFL xml file. Overrides: object.__init__